notetools.NoteHead
==================

.. inheritance-diagram:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead
   :private-bases:

.. autoclass:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.format

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.named_chromatic_pitch

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.tweak

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.written_pitch

Special Methods
---------------

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__eq__

   .. note:: Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ge__

   .. note:: Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__gt__

   .. note:: Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__le__

   .. note:: Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__lt__

   .. note:: Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ne__

   .. note:: Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__repr__

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__str__
